==========
loggertodb
==========


.. image:: https://img.shields.io/travis/openmeteo/loggertodb.svg
        :target: https://travis-ci.org/openmeteo/loggertodb

.. image:: https://codecov.io/github/openmeteo/loggertodb/coverage.svg
        :target: https://codecov.io/gh/openmeteo/loggertodb
        :alt: Coverage

.. image:: https://img.shields.io/pypi/v/loggertodb.svg
        :target: https://pypi.python.org/pypi/loggertodb

.. image:: https://readthedocs.org/projects/loggertodb/badge/?version=latest
        :target: https://loggertodb.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/openmeteo/loggertodb/shield.svg
     :target: https://pyup.io/repos/github/openmeteo/loggertodb/
     :alt: Updates



Insert meteorological station data to Enhydris

License
=======

Free software: GNU General Public License v3

Documentation
=============

https://loggertodb.readthedocs.io.
